#

    	sink filter

    	If you happen to find a motorized spinning knives underneath your sink,
    	this is the recommended removal procedure.

    	Step 1.
    		Pause.

    	Step 2.
    		Put on Thick Gloves.

    	Step 3.
    		The motorized spinning knives contraption might have batteries in it,
    		so be cautious!

    	Step 4.
    		Carefully, pull out the plug.

    	Step 5.
    		There are a lot of different spinning knife contraptions,
    		a lot of them might be similar though.

    		Consulting the installation manual is definitely recommended.

    	Step 6.
    		Place a plastic crate or water collector underneath the sink.

    	Step 7.
    		With your thick gloves still on, remove the contraption.

    	Step 8.
    		Install these parts.

    		Tri Clamp 1.5in Fitting:
    			https://amzn.to/3Sz1Msg

    		Tri Clamp Filter:
    			https://amzn.to/3HXT7Lb

    		2 Tri Clamp Ferrule Fittings:
    			https://amzn.to/42JZ5sk

    		EasyDrain 1½" 4-Way Cross Connector:
    			https://amzn.to/3uHUx9l

    		Sink Fitting:
    			https://amzn.to/3I0xmtV

    	Step 9.
    		Once installed, the filter might need to be
    		cleared every once in a while.